==> sandra-entities-2.0.2-sources.jar: com/cybelia/sandra/entities/Tour.java <==
package com.cybelia.sandra.entities;

import com.cybelia.sandra.entities.trace.SuiviTour;
import java.util.Date;
import java.util.List;
import org.nuiton.topia.persistence.TopiaEntity;

public interface Tour extends TopiaEntity {

    String PROPERTY_DATE_LIVRAISON = "dateLivraison";

    String PROPERTY_NUMERO = "numero";

    String PROPERTY_COMMENTAIRE = "commentaire";

    String PROPERTY_DATE_CHARGEMENT = "dateChargement";

    String PROPERTY_ACTIF = "actif";

    String PROPERTY_ETAPES = "etapes";

    String PROPERTY_CAMION = "camion";

    String PROPERTY_DEFAUT_CHAUFFEUR = "defautChauffeur";

    String PROPERTY_SUIVI_TOUR = "suiviTour";

    void setDateLivraison(Date dateLivraison);

    Date getDateLivraison();

    void setNumero(int numero);

    int getNumero();

    void setCommentaire(String commentaire);

    String getCommentaire();

    void setDateChargement(Date dateChargement);

    Date getDateChargement();

    void setActif(boolean actif);

    boolean isActif();

    boolean getActif();

    void addEtapes(Etape etapes);

    void addAllEtapes(List<Etape> etapes);

    void setEtapes(List<Etape> etapes);

    void removeEtapes(Etape etapes);

    void clearEtapes();

    List<Etape> getEtapes();

    Etape getEtapesByTopiaId(String topiaId);

    int sizeEtapes();

    boolean isEtapesEmpty();

    void setCamion(Camion camion);

    Camion getCamion();

    void setDefautChauffeur(Chauffeur defautChauffeur);

    Chauffeur getDefautChauffeur();

    void setSuiviTour(SuiviTour suiviTour);

    SuiviTour getSuiviTour();

} //Tour

==> sandra-entities-2.1-sources.jar: com/cybelia/sandra/entities/Tour.java <==
package com.cybelia.sandra.entities;

import com.cybelia.sandra.entities.trace.SuiviTour;
import java.util.Date;
import java.util.List;
import org.nuiton.topia.persistence.TopiaEntity;

public interface Tour extends TopiaEntity {

    String PROPERTY_DATE_LIVRAISON = "dateLivraison";

    String PROPERTY_NUMERO = "numero";

    String PROPERTY_COMMENTAIRE = "commentaire";

    String PROPERTY_DATE_CHARGEMENT_REEL = "dateChargementReel";

    String PROPERTY_ACTIF = "actif";

    String PROPERTY_DATE_CHARGEMENT_INITIALE = "dateChargementInitiale";

    String PROPERTY_NOTIFICATION_RETOUR_USINE = "notificationRetourUsine";

    String PROPERTY_ETAPES = "etapes";

    String PROPERTY_CAMION = "camion";

    String PROPERTY_DEFAUT_CHAUFFEUR = "defautChauffeur";

    String PROPERTY_SUIVI_TOUR = "suiviTour";

    void setDateLivraison(Date dateLivraison);

    Date getDateLivraison();

    void setNumero(int numero);

    int getNumero();

    void setCommentaire(String commentaire);

    String getCommentaire();

    void setDateChargementReel(Date dateChargementReel);

    Date getDateChargementReel();

    void setActif(boolean actif);

    boolean isActif();

    boolean getActif();

    void setDateChargementInitiale(Date dateChargementInitiale);

    Date getDateChargementInitiale();

    void setNotificationRetourUsine(Date notificationRetourUsine);

    Date getNotificationRetourUsine();

    void addEtapes(Etape etapes);

    void addAllEtapes(List<Etape> etapes);

    void setEtapes(List<Etape> etapes);

    void removeEtapes(Etape etapes);

    void clearEtapes();

    List<Etape> getEtapes();

    Etape getEtapesByTopiaId(String topiaId);

    int sizeEtapes();

    boolean isEtapesEmpty();

    void setCamion(Camion camion);

    Camion getCamion();

    void setDefautChauffeur(Chauffeur defautChauffeur);

    Chauffeur getDefautChauffeur();

    void setSuiviTour(SuiviTour suiviTour);

    SuiviTour getSuiviTour();

    Date getDateChargement();

    void setDateChargement(Date date);

    boolean hasCRTour();

} //Tour
